"use strict";

/* exported logger */

var Panel = require('./Panel');
var PanelControlElementType = require('../PanelControlElementType');
var PublicationListDialog = require('./PublicationListDialog');

var logger = require('../../logger');
var Functions = require('../../Functions');

function ProjectInfoPanel(params) {
  params.panelName = "info";
  Panel.call(this, params);
  var self = this;
  self._createInfoPanelGui();
  self._createInfoPanelLogic();
}

ProjectInfoPanel.prototype = Object.create(Panel.prototype);
ProjectInfoPanel.prototype.constructor = ProjectInfoPanel;

ProjectInfoPanel.prototype._createInfoPanelGui = function() {
  var self = this;
  var infoDiv = Functions.createElement({
    type : "div",
    name : "infoDiv",
    className : "searchPanel"
  });
  this.getElement().appendChild(infoDiv);
  this.setControlElement(PanelControlElementType.INFO_DIV, infoDiv);

  var infoTitle = Functions.createElement({
    type : "h5",
    content : "PROJECT INFO:"
  });
  infoDiv.appendChild(infoTitle);

  var dataTab = Functions.createElement({
    type : "div",
    style : "width:100%;display: table;border-spacing: 10px;"
  });
  infoDiv.appendChild(dataTab);

  var projectNameLabel = Functions.createElement({
    type : "div",
    content : "Name:"
  });
  var projectNameText = Functions.createElement({
    type : "div",
    style : "width:100%",
    name : "projectNameText"
  });
  this.setControlElement(PanelControlElementType.INFO_PROJECT_NAME_TEXT, projectNameText);
  dataTab.appendChild(self.createTableRow([ projectNameLabel, projectNameText ]));

  var projectVersionLabel = Functions.createElement({
    type : "div",
    content : "Version:"
  });
  var projectVersionText = Functions.createElement({
    type : "div",
    style : "width:100%",
    name : "projectVersionText"
  });
  this.setControlElement(PanelControlElementType.INFO_PROJECT_VERSION_TEXT, projectVersionText);
  dataTab.appendChild(self.createTableRow([ projectVersionLabel, projectVersionText ]));

  var projectDescriptionLabel = Functions.createElement({
    type : "div",
    content : "Description:"
  });
  var projectDescriptionText = Functions.createElement({
    type : "div",
    style : "width:100%",
    name : "projectDescriptionText"
  });
  this.setControlElement(PanelControlElementType.INFO_PROJECT_DESCRIOPTION_TEXT, projectDescriptionText);
  dataTab.appendChild(self.createTableRow([ projectDescriptionLabel, projectDescriptionText ]));

  var projectPublicationsLabel = Functions.createElement({
    type : "div",
    content : "Publications:"
  });

  var projectPublicationsDiv = Functions.createElement({
    type : "div"
  });
  var projectPublicationsText = Functions.createElement({
    type : "label",
    name : "projectPublicationsText",
  });
  this.setControlElement(PanelControlElementType.INFO_PROJECT_PUBLICATIONS_TEXT, projectPublicationsText);

  var projectPublicationsButton = Functions.createElement({
    type : "button",
    name : "projectPublicationsButton",
    content : "SHOW"
  });
  this.setControlElement(PanelControlElementType.INFO_PROJECT_SHOW_PUBLICATIONS_BUTTON, projectPublicationsButton);
  projectPublicationsDiv.appendChild(projectPublicationsText);
  projectPublicationsDiv.appendChild(projectPublicationsButton);

  dataTab.appendChild(self.createTableRow([ projectPublicationsLabel, projectPublicationsDiv ]));

  var projectOriginalFileLabel = Functions.createElement({
    type : "div",
    content : "Original file:"
  });
  var projectOriginalFileButton = Functions.createElement({
    type : "button",
    name : "projectOriginalFileButton",
    content : "Download",
  });
  this.setControlElement(PanelControlElementType.INFO_PROJECT_GET_ORIGINAL_FILE_BUTTON, projectOriginalFileButton);
  dataTab.appendChild(self.createTableRow([ projectOriginalFileLabel, projectOriginalFileButton ]));
  
  
  var dialogDiv = Functions.createElement({
    type : "div",
  });
  
  this.publicationListDialog = new PublicationListDialog({
    customMap: self.getMap(),
    element: dialogDiv,
  });
  
};

ProjectInfoPanel.prototype._createInfoPanelLogic = function() {
  var self = this;

  var downloadSourceButton = self.getControlElement(PanelControlElementType.INFO_PROJECT_GET_ORIGINAL_FILE_BUTTON);
  var showPublicationsButton = self.getControlElement(PanelControlElementType.INFO_PROJECT_SHOW_PUBLICATIONS_BUTTON);

  downloadSourceButton.onclick = function() {
    return self.downloadSourceFile();
  };
  showPublicationsButton.onclick = function() {
    return self.showPublicationListDialog();
  };
};

ProjectInfoPanel.prototype.downloadSourceFile = function() {
  var self = this;
  return ServerConnector.getProjectSourceDownloadUrl().then(function(url) {
    return self.downloadFile(url);
  }).catch(GuiConnector.alert);
};

ProjectInfoPanel.prototype.showPublicationListDialog = function() {
  return this.publicationListDialog.show();
};

ProjectInfoPanel.prototype.refresh = function() {
  var self = this;

  var projectNameText = self.getControlElement(PanelControlElementType.INFO_PROJECT_NAME_TEXT);
  var projectVersionText = self.getControlElement(PanelControlElementType.INFO_PROJECT_VERSION_TEXT);
  var projectDescriptionText = self.getControlElement(PanelControlElementType.INFO_PROJECT_DESCRIOPTION_TEXT);
  var projectPublicationsText = self.getControlElement(PanelControlElementType.INFO_PROJECT_PUBLICATIONS_TEXT);

  return ServerConnector.getProject().then(function(project) {
    projectNameText.innerHTML = project.getName();
    projectVersionText.innerHTML = project.getVersion();
    projectDescriptionText.innerHTML = project.getDescription();
    projectPublicationsText.innerHTML = project.getPublicationCount();
    return null;
  });
};

ProjectInfoPanel.prototype.init = function() {
  return this.refresh();
};

module.exports = ProjectInfoPanel;
