"use strict";

/* exported logger */

var Panel = require('./Panel');
var PanelControlElementType = require('../PanelControlElementType');

var GuiConnector = require('../../GuiConnector');
var Functions = require('../../Functions');
var logger = require('../../logger');

function UserPanel(params) {
  params.panelName = "user";
  Panel.call(this, params);

  var self = this;
  
  self._createLoginTab();
  self._createUserDataTab();
  
  var loginButton = self.getControlElement(PanelControlElementType.USER_TAB_LOGIN_BUTTON);
  var logoutButton = self.getControlElement(PanelControlElementType.USER_TAB_LOGOUT_BUTTON);
  loginButton.onclick = function(){
    var login = self.getControlElement(PanelControlElementType.USER_TAB_LOGIN_INPUT_TEXT).value;
    var password = self.getControlElement(PanelControlElementType.USER_TAB_PASSOWRD_INPUT_TEXT).value;
    
    return ServerConnector.login(login, password).then(function(){
      window.location.reload(false);
    }).catch(function(problem){
      GuiConnector.alert(problem);
    });
  };
  
  logoutButton.onclick = function(){
    return ServerConnector.logout().then(function(){
      window.location.reload(false);
    }).catch(function(problem){
      GuiConnector.alert(problem);
    });
  };
}

UserPanel.prototype = Object.create(Panel.prototype);
UserPanel.prototype.constructor = UserPanel;

UserPanel.prototype._createLoginTab = function() {
  var self = this;
  var loginTabDiv = Functions.createElement({type:"div", name:"userLoginTab", className:"searchPanel" });
  this.getElement().appendChild(loginTabDiv);
  this.setControlElement(PanelControlElementType.USER_TAB_LOGIN_DIV, loginTabDiv);

  var authirizationTitle = Functions.createElement({type:"h5", content:"AUTHORIZATION FORM:"} );
  loginTabDiv.appendChild(authirizationTitle);

  var authorizationFormTab = Functions.createElement({type:"div", style:"width:100%;display: table;border-spacing: 10px;"} );
  loginTabDiv.appendChild(authorizationFormTab);
  
  var loginLabel = Functions.createElement({type:"div", content:"LOGIN:"} );
  var loginInput = Functions.createElement({type:"input", inputType:"text", style:"width:100%", name:"loginText"} );
  this.setControlElement(PanelControlElementType.USER_TAB_LOGIN_INPUT_TEXT, loginInput);

  authorizationFormTab.appendChild(self.createTableRow([loginLabel, loginInput]));
  
  var passwordLabel = Functions.createElement({type:"div", content:"LOGIN:"} );
  var passwordInput = Functions.createElement({type:"input", inputType:"password", style:"width:100%", name:"passwordText"} );
  this.setControlElement(PanelControlElementType.USER_TAB_PASSOWRD_INPUT_TEXT, passwordInput);

  authorizationFormTab.appendChild(self.createTableRow([passwordLabel, passwordInput]));

  var centerTag = Functions.createElement({type:"center"} );
  loginTabDiv.appendChild(centerTag);

  var loginButton = Functions.createElement({type:"button", name:"loginButton", content:"LOGIN"} );
  centerTag.appendChild(loginButton);
  this.setControlElement(PanelControlElementType.USER_TAB_LOGIN_BUTTON, loginButton);

};

UserPanel.prototype._createUserDataTab = function() {
  var self = this;
  var userDataDiv = Functions.createElement({type:"div", name:"userDataTab", className:"searchPanel", style:"display:none"});
  this.getElement().appendChild(userDataDiv);
  this.setControlElement(PanelControlElementType.USER_TAB_USER_DIV, userDataDiv);

  var userDataTitle = Functions.createElement({type:"h3", content:'<img src="./resources/images/profile.png" border="0" align="left"/><br/>WELCOME<br/>'} );
  userDataDiv.appendChild(userDataTitle);

  var userDataFormTab = Functions.createElement({type:"div", style:"width:100%;display: table;border-spacing: 10px;"} );
  userDataDiv.appendChild(userDataFormTab);
  
  var loginLabel = Functions.createElement({type:"span", content:"LOGIN:", style:"color:#999999"} );
  var loginText = Functions.createElement({type:"span", name:"loginValue"} );
  this.setControlElement(PanelControlElementType.USER_TAB_LOGIN_TEXT, loginText);
  userDataDiv.appendChild(self.createTableRow([loginLabel, loginText]));
  
  var nameLabel = Functions.createElement({type:"span", content:"NAME:", style:"color:#999999"} );
  var nameText = Functions.createElement({type:"span", name:"nameValue"} );
  this.setControlElement(PanelControlElementType.USER_TAB_NAME_TEXT, nameText);
  userDataDiv.appendChild(self.createTableRow([nameLabel, nameText]));
  
  var surnameLabel = Functions.createElement({type:"span", content:"SURNAME:", style:"color:#999999"} );
  var surnameText = Functions.createElement({type:"span", name:"surnameValue"} );
  this.setControlElement(PanelControlElementType.USER_TAB_SURNAME_TEXT, surnameText);
  userDataDiv.appendChild(self.createTableRow([surnameLabel, surnameText]));
  
  var emailLabel = Functions.createElement({type:"span", content:"EMAIL:", style:"color:#999999"} );
  var emailText = Functions.createElement({type:"span", name:"emailValue"} );
  this.setControlElement(PanelControlElementType.USER_TAB_EMAIL_TEXT, emailText);
  userDataDiv.appendChild(self.createTableRow([emailLabel, emailText]));
  
  var centerTag = Functions.createElement({type:"center"} );
  userDataDiv.appendChild(centerTag);

  var logoutButton = Functions.createElement({type:"button", name:"logoutButton", content:"LOGOUT"} );
  centerTag.appendChild(logoutButton);
  this.setControlElement(PanelControlElementType.USER_TAB_LOGOUT_BUTTON, logoutButton);  
};

UserPanel.prototype.showLoginPage = function() {
  var self = this;
  var userLoginTabDiv = self.getControlElement(PanelControlElementType.USER_TAB_LOGIN_DIV);
  var userDataTabDiv = self.getControlElement(PanelControlElementType.USER_TAB_USER_DIV);

  userLoginTabDiv.style.display = "block";

  userDataTabDiv.style.display = "none";
};

UserPanel.prototype.showUserProfilePage = function(user) {
  var self = this;
  var userLoginTabDiv = self.getControlElement(PanelControlElementType.USER_TAB_LOGIN_DIV);
  var userDataTabDiv = self.getControlElement(PanelControlElementType.USER_TAB_USER_DIV);
  var loginText = self.getControlElement(PanelControlElementType.USER_TAB_LOGIN_TEXT);
  var nameText = self.getControlElement(PanelControlElementType.USER_TAB_NAME_TEXT);
  var surnameText = self.getControlElement(PanelControlElementType.USER_TAB_SURNAME_TEXT);
  var emailText = self.getControlElement(PanelControlElementType.USER_TAB_EMAIL_TEXT);

  userLoginTabDiv.style.display = "none";

  userDataTabDiv.style.display = "block";
  
  loginText.innerHTML = user.getLogin(); 
  nameText.innerHTML = user.getName(); 
  surnameText.innerHTML = user.getSurname(); 
  emailText.innerHTML = user.getEmail(); 
};

UserPanel.prototype.init = function() {
  var self = this;
  return ServerConnector.getLoggedUser().then(function(user) {
    if (user.getLogin() === "anonymous") {
      self.showLoginPage();
    } else {
      self.showUserProfilePage(user);
    }
    return Promise.resolve();
  });
};

module.exports = UserPanel;
