"use strict";

var AbstractInfoWindow = require('./AbstractInfoWindow');
var Reaction = require('../data/Reaction');
var ReactionMarker = require('../marker/ReactionMarker');

/**
 * Class representing info window that should be opened when clicking on
 * reaction.
 */
function ReactionInfoWindow(reactionData, map) {
  // call super constructor
  AbstractInfoWindow.call(this, reactionData, map);

  if (reactionData instanceof ReactionMarker) {
    this.setReactionData(reactionData.getReactionData());
  } else {
    this.setReactionData(reactionData);
  }

  var reaction = this.getReactionData();
  if (reaction === null || reaction === undefined) {
    throw new Error("Opening window without reaction specified");
  }
  var point = reaction.getCenter();
  var latLng = this.getCustomMap().fromPointToLatLng(point);
  this.googleInfowindow = new google.maps.InfoWindow({
    content : this.content,
    position : latLng
  });
  this.googleInfowindow.open(this.getCustomMap().getGoogleMap(), this.getGoogleMarker());
  this.update(this._reactionData);
}

ReactionInfoWindow.prototype = Object.create(AbstractInfoWindow.prototype);
ReactionInfoWindow.prototype.constructor = ReactionInfoWindow;

/**
 * Methods that creates and return html code with the content of the window.
 * 
 * @returns {String} representing html code for content of the info window
 */
ReactionInfoWindow.prototype.createContentDiv = function() {
  return Promise.resolve(document.createElement("div"));
};

/**
 * Returns array with data taken from all known {@link OverlayCollection}.
 * 
 * @returns array with data from {@link OverlayCollection}
 */
ReactionInfoWindow.prototype.getOverlaysData = function(general) {
  return this.getCustomMap().getTopMap().getOverlayDataForReaction(this.getReactionData(), general);
};

ReactionInfoWindow.prototype.getReactionData = function() {
  return this._reactionData;
};

ReactionInfoWindow.prototype.setReactionData = function(reactionData) {
  if (reactionData === undefined || reactionData === null) {
    this._reactionData = null;
  } else if (reactionData instanceof Reaction) {
    this._reactionData = reactionData;
  } else {
    throw "Parameter must be of Reaction type, but found" + reactionData;
  }
};

module.exports = ReactionInfoWindow;
