"use strict";

var Helper = require('../../helper');

require('../../mocha-config.js');

var Chemical = require('../../../../main/js/map/data/Chemical');
var ChemicalPanel = require('../../../../main/js/gui/leftPanel/ChemicalPanel');
var PanelControlElementType = require('../../../../main/js/gui/PanelControlElementType');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../../logger');

describe('ChemicalPanel', function() {

  var helper;
  before(function() {
    helper = new Helper();
  });

  it('contructor', function() {
    var map = helper.createCustomMap();
    helper.createChemicalDbOverlay(map);

    new ChemicalPanel({
      element : testDiv,
      customMap : map
    });
    assert.equal(logger.getWarnings().length, 0);
  });

  it('createChemicaleader for empty', function() {
    var map = helper.createCustomMap();
    helper.createChemicalDbOverlay(map);

    var panel = new ChemicalPanel({
      element : testDiv,
      customMap : map
    });

    assert.ok(panel.createPreamble().innerHTML.indexOf("NOT FOUND") > 0);
  });

  it('createChemicaleader for empty', function() {
    var map = helper.createCustomMap();
    helper.createChemicalDbOverlay(map);

    var panel = new ChemicalPanel({
      element : testDiv,
      customMap : map
    });

    assert.ok(panel.createPreamble(new Chemical()).innerHTML.indexOf("NOT FOUND") > 0);
  });

  it('on searchResults changed', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var chemicalDbOverlay = helper.createChemicalDbOverlay(map);

    new ChemicalPanel({
      element : testDiv,
      customMap : map
    });

    return chemicalDbOverlay.searchByQuery("rotenone").then(function() {
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(testDiv.innerHTML.indexOf("marker/mechanism") >= 0);
    });
  });

  it('searchByQuery', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    helper.createChemicalDbOverlay(map);

    var panel = new ChemicalPanel({
      element : testDiv,
      customMap : map
    });

    panel.getControlElement(PanelControlElementType.SEARCH_INPUT).value = "rotenone";

    return panel.searchByQuery().then(function() {
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(testDiv.innerHTML.indexOf("Rotenone ") >= 0);
    });
  });

});
