"use strict";

var Helper = require('../../helper');

require('../../mocha-config.js');

var OverlayPanel = require('../../../../main/js/gui/leftPanel/OverlayPanel');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../../logger');

describe('OverlayPanel', function() {

  var helper;
  before(function() {
    helper = new Helper();
  });

  it('contructor', function() {
    var map = helper.createCustomMap();

    new OverlayPanel({
      element : testDiv,
      customMap : map
    });
    assert.equal(logger.getWarnings().length, 0);
  });

  it('refresh', function() {
    var map = helper.createCustomMap();

    var panel = new OverlayPanel({
      element : testDiv,
      customMap : map
    });

    return panel.refresh().then(function() {
      assert.ok(panel.getElement().innerHTML.indexOf("testLayout") >= 0);
      assert.ok(panel.getElement().innerHTML.indexOf("YOU ARE NOT LOGGED") >= 0);
    });
  });

  it('createRow', function() {
    var map = helper.createCustomMap();

    var overlay = helper.createLayout();
    overlay.setInputDataAvailable(true);
    overlay.setCreator("me");
    map.getModel().addLayout(overlay);

    var panel = new OverlayPanel({
      element : testDiv,
      customMap : map
    });

    var row = panel.createOverlayRow(overlay);
    assert.ok(row);

    var buttons = row.getElementsByTagName("button");
    var openButton = null;
    for (var i = 0; i < buttons.length; i++) {
      var name = buttons[i].getAttribute("name");
      if (name !== undefined && name.indexOf("editButton") >= 0) {
        openButton = buttons[i];
      }
    }
    assert.ok(openButton);
    openButton.onclick();
  });
  it('download', function() {
    var map = helper.createCustomMap();

    var overlay = helper.createLayout();
    overlay.setInputDataAvailable(true);
    map.getModel().addLayout(overlay);

    var panel = new OverlayPanel({
      element : testDiv,
      customMap : map
    });

    return panel.refresh().then(function() {
      var buttons = panel.getElement().getElementsByTagName("button");
      var downloadButton;
      for (var i = 0; i < buttons.length; i++) {
        var name = buttons[i].getAttribute("name");
        if (name !== undefined && name.indexOf("download-overlay") >= 0) {
          downloadButton = buttons[i];
        }
      }
      assert.ok(downloadButton);
      assert.notOk(panel.getLastDownloadUrl());
      return downloadButton.onclick();
    }).then(function() {
      assert.ok(panel.getLastDownloadUrl());
    });
  });

  it('openAddOverlayDialog', function() {
    var map = helper.createCustomMap();

    var panel = new OverlayPanel({
      element : testDiv,
      customMap : map
    });

    return panel.openAddOverlayDialog();
  });

  it('parse overlay file', function() {
    var map = helper.createCustomMap();

    var panel = new OverlayPanel({
      element : testDiv,
      customMap : map
    });

    return ServerConnector.readFile("testFiles/overlay/good.txt").then(function(fileContent) {
      var obj = panel.parseFile(fileContent);
      assert.equal(obj.name, "example name");
      assert.equal(obj.description, "layout description");
      assert.equal(obj.type, "GENERIC");
    });
  });

});
