"use strict";

var Helper = require('../../helper');

require('../../mocha-config.js');

var Alias = require('../../../../main/js/map/data/Alias');
var SearchPanel = require('../../../../main/js/gui/leftPanel/SearchPanel');
var PanelControlElementType = require('../../../../main/js/gui/PanelControlElementType');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../../logger');

describe('SearchPanel', function() {

  var helper;
  before(function() {
    helper = new Helper();
  });

  it('contructor', function() {
    var map = helper.createCustomMap();
    helper.createSearchDbOverlay(map);

    new SearchPanel({
      element : testDiv,
      customMap : map
    });
    assert.equal(logger.getWarnings().length, 0);
  });

  it('on searchResults changed', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var searchDbOverlay = helper.createSearchDbOverlay(map);

    new SearchPanel({
      element : testDiv,
      customMap : map
    });

    return searchDbOverlay.searchByCoordinates(map.getModel().getId(), new google.maps.Point(26547.33, 39419.29)).then(
        function() {
          assert.equal(logger.getWarnings().length, 0);
          assert.ok(testDiv.innerHTML.indexOf("Reaction") >= 0);
        });
  });

  it('on searchResults changed 2', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var searchDbOverlay = helper.createSearchDbOverlay(map);

    new SearchPanel({
      element : testDiv,
      customMap : map
    });

    return searchDbOverlay.searchByQuery("s1", false).then(function() {
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(testDiv.innerHTML.indexOf("s1") >= 0);
    });
  });

  it('search by query with no results', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    helper.createSearchDbOverlay(map);

    var panel = new SearchPanel({
      element : testDiv,
      customMap : map
    });

    panel.getControlElement(PanelControlElementType.SEARCH_INPUT).value = "s1";
    
    return panel.searchByQuery().then(function() {
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(testDiv.innerHTML.indexOf("s1") >= 0);
    });
  });

  it('createAliasElement', function() {
    var aliasObj = {
      symbol : "S1_SYMB",
      formerSymbols : [],
      references : [ {
        name : "HMDB03141",
        type : "HMDB",
        link : "http://www.hmdb.ca/metabolites/HMDB03141",
        idObject : 933405
      }, {
        name : "CHEBI:28870",
        type : "Chebi",
        link : "http://www.ebi.ac.uk/chebi/searchId.do?chebiId\u003dCHEBI%3A28870",
        idObject : 933406
      }, {
        name : "C05488",
        type : "Kegg Compound",
        link : "http://www.kegg.jp/entry/C05488",
        idObject : 933407
      } ],
      modelId : 18931,
      synonyms : [ "syn44" ],
      description : "DESCRIPTION",
      type : "Simple molecule",
      abbreviation : "ABREVIATION",
      name : "s1",
      bounds : {
        x : 170.0,
        y : 171.5,
        width : 70.0,
        height : 25.0
      },
      formula : "FORMULA",
      id : 380217
    };
    var alias = new Alias(aliasObj);

    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    helper.createSearchDbOverlay(map);

    var panel = new SearchPanel({
      element : testDiv,
      customMap : map
    });

    var aliasDiv = panel.createAliasElement(alias);
    assert.ok(aliasDiv.innerHTML);
  });

  it('createLabelText for indefined', function() {
    var map = helper.createCustomMap();
    helper.createSearchDbOverlay(map);

    var panel = new SearchPanel({
      element : testDiv,
      customMap : map
    });

    var res = panel.createLabelText();
    assert.notOk(res.innerHTML);
  });

});
